<template>
    <v-card v-if="product" class="full">
        <div class="_pcard">

            <div class="_pimage">
                <nuxt-link
                    :to="product.product_link"
                >
                    <Lazy
                        :src="product.image"
                        :alt="product.name"
                    >
                    </Lazy>
                </nuxt-link>
            </div>

            <div class="_pdata pa-3">
                <div class="_pname">
                    <nuxt-link :to="product.product_link">
                        {{ product.name }}
                    </nuxt-link>
                </div>
                <div class="_prprice" v-text="product.regular_price"></div>
                <div class="_pdesc" v-html="product.description_short"></div>
            </div>

            <div class="_paction pa-3">
                <div
                    v-if="product.all_combinations && product.product_type != 'Stem'"
                >
                    <div
                      class="_attributes"
                      :key="ind"
                      v-for="(comb, ind) in product.all_combinations.values"
                    >
                      <div :class="'length_title ' + ind + '_hide'">{{ ind }} </div>
                      <div :class="'row flex wrap ' + ind + '_hide'">
                        <div class="_abs" v-for="(cc, i) in comb" :key="i">
                          <div>
                            <div @click="changeAttribute(cc)" :class="'length_box' +  getSelected(cc)"> {{ cc.value }} </div>
                          </div>
                        </div>
                      </div>
                    </div>
                    <div class="length_title raleway" v-if="product.product_type == 'Box'"> PALLETS</div>
                    <div class="length_title raleway" v-else-if="product.product_type == 'Stem'">STEMS (Average 1,330 Pounds)</div>
                </div>

                <div class="mt-3">
                    <v-select
                        :items="product.quantities"
                        v-model="qty"
                        outline
                        label="Quantity"
                    ></v-select>
                </div>

                <div class="length_title ml-0 w-100" v-if="product.name.includes('Hi-Tensile')">
                  STEMS (Ave. 1,330 Lbs)
                </div>

                <div class="length_title ml-0 w-100" v-if="product.name.includes('Black Annealed Stem Wire')">
                  STEMS (Ave. 1,900 Lbs)
                </div>

                <v-btn
                    v-if="comb_not_found"
                    large
                    color="error"
                    block
                    disabled
                >
                    Not Available
                </v-btn>

                <v-btn
                    v-else
                    large
                    color="secondary"
                    block
                    :loading="addProcess"
                    @click="addToCart"
                >
                    Add to Cart
                </v-btn>
            </div>

        </div>
    </v-card>
</template>

<script>
import axios from 'axios'

export default {
    props: ['product'],
    data () {
        return {
            name: this.product.name,
            comb_not_found: false,
            qty: 1,
            maxQty: null,
            addProcess: false
        }
    },
    created () {
        this.getQty();
    },
    methods: {
        changeAttribute(cc) {
            var iag = cc.id_attribute_group; //Id attribute group
            var iav = cc.value; //Id Attribute value
            var current_combination = this.product.all_combinations.default_combination_values;
            var ac = this.product.all_combinations.combinations; //All attribute combinations
            this.product.all_combinations.default_combination_values[iag] = cc.value; //Triggered change
            var dc = this.product.all_combinations.default_combination_values;
            this.product.all_combinations.price_impact[cc.value];
            var matches = false;
            for (var comb in ac) {
                for (var d in dc) {
                if (d && d !== 'undefined') {
                    if (ac[comb][d] != dc[d]) {
                    break;
                    } else {
                    for (var dd in dc) {
                        if (ac[comb][dd] == dc[d]) {
                            matches = true;
                        } else {
                            matches = false;
                        }
                    }
                    }
                }
                }
                if (matches) {
                    this.comb_not_found = false;
                    this.product.id_product_attribute = comb;
                    break;
                } else {
                this.comb_not_found = true;
                }
            }
            this.getQty(); //Trigger qty change
            this.getPrice(); //Trigger price change
            this.getMaxQty();
            // this.wasPrice(this.product.regular_price);
        },
        changeQty(add) {
            if (add) {
                this.qty = +this.qty + 1;
                if (this.product.product_type == 'Bale') {
                    if (this.qty <= 4 && this.product.quantity < this.qty) {
                        this.qty = 5;
                    }
                }
            } else {
                var qty = this.qty;
                this.qty = +this.qty - 1;
                if (this.product.product_type == 'Bale') {
                if (this.qty <= 4 && this.product.quantity < this.qty) {
                    this.qty = this.product.quantity;
                }
                }

                if (this.qty < this.getMinimalQty()) {
                this.qty = qty;
                }

            }
        },
        getMaxQty() {
            var ipa = this.product.id_product_attribute;
            if (this.product.id_product_attribute) {
                this.maxQty = Number(this.product.all_combinations.max_bundles_per_pallet[ipa]);
            }
        },
        getSelected(cc) {
            var iag = cc.id_attribute_group; //Id attribute group
            var iav = cc.value; //Id Attribute value
            var current_combination = this.product.id_product_attribute;
            var dc = this.product.all_combinations.default_combination_values; //All attribute combinations
            if (dc[iag] == cc.value) {
                return ' active';
            }

            return '';
        },
        getMinimalQty() {
            if (
              this.product &&
              this.product.id_product_attribute &&
              this.product.all_combinations &&
              this.product.all_combinations['minimal']
            ) {
                return this.product.all_combinations['minimal'][this.product.id_product_attribute];
            } else {
                return this.product.minimal_quantity;
            }
        },
        getQty() {

            if (
              this.product &&
              this.product.id_product_attribute &&
              this.product.all_combinations &&
              this.product.all_combinations['minimal']
            ) {
                this.qty = +this.product.all_combinations['minimal'][this.product.id_product_attribute];
            } else {
                this.qty = +this.product.minimal_quantity;
            }

            return +this.qty;
        },
        getPrice() {

            var ipa = this.product.id_product_attribute;

            if (this.product.id_product_attribute) {

                this.product.price = this.cNumber(this.product.all_combinations.price_impact[ipa]);
                this.product.regular_price = this.cNumber(this.product.all_combinations.price_impact[ipa]);

            } else {

                var p = this.product.regular_price;
                this.product.price = this.cNumber(p);
                this.product.regular_price = this.cNumber(p);

            }

            return this.product.price;
        },
        cNumber: function(val) {
            var p = val.replace(',','');
            return Number(p).toLocaleString('en-US', { style: 'currency', currency: 'USD' })
        },
        addToCart() {
            if (this.qty < this.getMinimalQty()) {
                this.$store.commit('showSnackBar', 'Wire quantity should be at least ' + this.getMinimalQty);
                return false;
            }
            this.addProcess = true;
            var qty = this.qty;
            this.setProductToCart(this.qty);
        },
        setProductToCart(qty) {
            var ip =  this.product.id_product;
            var ipa = this.product.id_product_attribute;

            var form_data = new FormData();
            form_data.append('id_product', ip);
            form_data.append('id_product_attribute', ipa);
            form_data.append('qty', qty);

            axios.post(this.$store.state.api_domain + '?comp=process&action=addToCart', form_data, {withCredentials: true})
            .then((res) => {
                this.addProcess = false;
                this.maxBundleLoad = false;
                if (res.data.status == 'error') {
                this.addToCart();
                }
                if (res.data.status == 'success') {
                this.$store.commit('setCart', res.data.message);
                this.dialog = false;
                this.$store.commit('cartDrawer', true);
                if (res.data.cache_reset) {
                    var cache_key = 'product_' + ip;
                    this.$cache.del(cache_key);
                }
                }
            })
            .catch((e) => {
                this.addProcess = false;
                console.log(e);
            });
        },
    },
    watch: {
    }
}
</script>
